@@ -2,7 +2,7 @@ use super::Provider;
 use crate::nixpacks::{
     app::App,
     environment::Environment,
-    nix::{NixConfig, Pkg},
+    nix::Pkg,
     phase::{SetupPhase, StartPhase},
 };
 use anyhow::Result;
@@ -20,25 +20,22 @@ impl Provider for DenoProvider {
         app.find_match(&re, "**/*.ts")
     }
 
-    fn setup(&self, _app: &App, _env: &Environment) -> Result<SetupPhase> {
-        Ok(SetupPhase::new(NixConfig::new(vec![
-            Pkg::new("pkgs.stdenv"),
-            Pkg::new("pkgs.deno"),
-        ])))
+    fn setup(&self, _app: &App, _env: &Environment) -> Result<Option<SetupPhase>> {
+        Ok(Some(SetupPhase::new(vec![Pkg::new("deno")])))
     }
 
-    fn start(&self, app: &App, _env: &Environment) -> Result<StartPhase> {
+    fn start(&self, app: &App, _env: &Environment) -> Result<Option<StartPhase>> {
         // Find the first index.ts or index.js file to run
         let matches = app.find_files("**/index.[tj]s")?;
         let path_to_index = match matches.first() {
             Some(m) => m.to_string(),
-            None => return Ok(StartPhase::default()),
+            None => return Ok(None),
         };
 
         let relative_path_to_index = app.strip_source_path(&path_to_index)?;
-        return Ok(StartPhase::new(format!(
+        return Ok(Some(StartPhase::new(format!(
             "deno run --allow-all {}",
             relative_path_to_index
-        )));
+        ))));
     }
 }
